---
title: Coupled Free-Flow and Porous Media Flow Models in DuMu<sup>X</sup>
---

# Motivation

## Environmental and Agricultural Issues

![](img/FFPM_radiation.gif){style="width: 60%; margin: auto; "}
<figcaption align = "center">
<font size = "2">
Fig.1 - Evaporation of soil water (Heck et al. (2020))<sup>1</sup>
</font>
</figcaption>

* Evaporation of soil water
* Soil salinization
* Underground storage (e.g. CO2, atmoic waste)

## Technical Issues

![](img/FFPM_filter_gv_t_closeup.png){style="width: 45%; align: left;"}
<figcaption align = "center">
<font size = "2">
Fig.2 - Filter (Schneider et al. (2023))<sup>2</sup>
</font>
</figcaption>

* Fuel cells
* Filters (e.g. air)
* Heat exchangers (e.g. CPU cooling)

## Biological Issues

![](img/FFPM_braintissue.png){style="width: 25%;  align: left;"}
<figcaption align = "center">
<font size = "2">
Fig.3 - Brain tissue (Koch et al. (2020))<sup>3</sup>
</font>
</figcaption>

* Brain tissue
* Leaf structure

# Model Overview

## Conceptual Physical Model
<img src=img/FFPM-PhysicalModelOverview.png width="80%">
<figcaption align = "center">
<font size = "2">
Fig.4 - Coupled dynamics at the soil-atmosphere interface (Photo: Edward Coltman)
</font>
</figcaption>

## Conceptual Physical Model
![](img/FFPM_A02_summary_hp1.png){style="width: 80%;  align: left;"}
<figcaption align = "center">
<font size = "2">
Fig.5 - Exchange processes at the free-flow porous-medium interface at different scales (Photo: Martin Schneider)
</font>
</figcaption>

## Mathematical Model: Overview

![](img/FFPM-ModelConceptColumn.png){style="width: 15%; margin: auto; float: left;"}

<font size = "6">

**Freeflow:**

* Stokes / Navier-Stokes / RANS
* 1-phase, n-components, non-equilibrium

**Interface condtions:**

* no thickness, no storage
* local thermodynamic equilibrium
* continuity of fluxes
* continuity of state variables

**Porous media:**

* Darcy/ Forchheimer / Richards
* m-phases, n-components, non-isothermal

</font>

## Mathematical Model: Freeflow
<img src=img/FFPM-freeflowsymbol.png width="40%">

## Mathematical Model: Freeflow

* Total mass balance
$$
\frac{\partial \rho_g \textbf{v}_g}{\partial t} + \nabla \cdot (\rho_g \textbf{v}_g \textbf{v}_g^T) - \nabla \cdot (\mathbf{\tau}_g + \mathbf{\tau}_{g,t})  +\nabla \cdot (p_g\textbf{I})- \rho_g \textbf{g} = 0
$$

* Momentum balance
$$
\frac{\partial \left(\rho_g X^\kappa_g\right)}{\partial t} + \nabla \cdot \left( \rho_g \textbf{v}_g X^\kappa_g - \mathbf{j}_{\text{diff}}^\kappa\right) - q^\kappa = 0
$$

* Component mass balance
$$
\frac{\partial (\rho_g u_g) }{\partial t} + \nabla \cdot (\rho_g h_g \textbf{v}_g) + \sum_{i} {\nabla \cdot (h_g^\kappa \textbf{j}_{\text{diff},t}^\kappa)} - \nabla \cdot ( (\lambda_{g} + \lambda_{t}) \nabla T) = 0
$$

## Mathematical Model: Porous Medium Flow
<img src=img/FFPM-pmfsymbol.png width="40%">

## Mathematical Model: Porous Medium Flow

* Component mass balance
$$
\sum\limits_{\alpha \in \{\text{l, g} \}} \left(\phi \frac{\partial \left(\rho_\alpha S_\alpha X_\alpha^\kappa\right)}{\partial t } + \nabla \cdot \textbf{v}_\alpha\rho_\alpha X_\alpha^\kappa + \sum_\kappa \nabla \cdot \left(  \textbf{D}_{pm,\alpha}^\kappa\rho_\alpha\nabla X_\alpha^\kappa \right)\right) = 0
$$

* Darcy velocity
$$
\textbf{v}_\alpha = - \frac{k_{r,\alpha}}{\mu_\alpha} K \left(\nabla p_\alpha - \rho_\alpha \textbf{g}\right)
$$

* Energy balance
$$
\sum\limits_{\alpha \in \{\text{l, g} \}}\left(\phi\frac{\partial \left(\rho_\alpha S_\alpha u_\alpha\right)}{\partial t} + \nabla \cdot \left(\rho_\alpha h_\alpha \textbf{v}_\alpha \right)\right) + \left(1-\phi\right) \frac{\partial \left(\rho_s c_{p,s}T\right)}{\partial t} - \nabla\cdot \left(\lambda_{pm} \nabla T \right) = 0
$$


## Mathematical Model: Coupling Conditions

<img src=img/FFPM-couplingsymbol.png width="30%">

* Total mass condition
$$
[(\rho_g \textbf{v}_g) \cdot \textbf{n}]^{\text{ff}} = - [(\rho_g \textbf{v}_g + \rho_w \textbf{v}_w) \cdot \textbf{n}]^{\text{pm}}
$$

## Mathematical Model: Coupling Conditions
<img src=img/FFPM-BJS.png width="30%">

* Momentum (tangential)condition
$$
\left[\left(- \textbf{v}_g - \frac{\sqrt{(\textbf{K}\textbf{t}_i)\cdot \textbf{t}_i}}{\alpha_{BJ}} (\nabla \textbf{v}_g + \nabla \textbf{v}_g^T)\textbf{n} \right) \cdot \textbf{t}_i \right]^{\text{ff}} = 0\, , \quad i \in \{1, .. ,\, d-1\}\,
$$

## Mathematical Model: Coupling Conditions

* Momentum (normal) condition
$$
[((\rho_g \textbf{v}_g \textbf{v}_g^T - (\mathbf{\tau}_g + \mathbf{\tau}_{g,t}) + p_g\textbf{I}) \textbf{n} )]^{\text{ff}} = [(p_g\textbf{I})\textbf{n}]^{\text{pm}}\,
$$

* Component mass condition
$$
[(\rho_g X_g^\kappa \textbf{v}_g + \textbf{j}_{\text{diff}, t}) \cdot \textbf{n}]^{\text{ff}} = - \left[\left( \sum_{\alpha} (\rho_{\alpha} X_{\alpha}^\kappa \textbf{v}_\alpha + \textbf{j}^\kappa_{\text{diff}, \alpha})\right) \cdot \textbf{n}\right]^{\text{pm}}\,
$$

* Energy condition
$$
\left[\left(\rho_g h_g \textbf{v}_g + \sum_i h_g^\kappa \textbf{j}_{\text{diff},g}^\kappa + \lambda_{g}\nabla T\right)\cdot \textbf{n}\right]^{\text{ff}} = - \left[\left( \sum_\alpha (\rho_\alpha h_\alpha \textbf{v}_\alpha + \sum_i h_\alpha^\kappa \textbf{j}_{\text{diff},\alpha}^\kappa) - \lambda_{\text{pm}}\nabla T\right)\cdot \textbf{n}\right]^{\text{pm}}\,
$$

## Numerical Model: Coupled Model
<img src=img/FFPM-numericalmodel.png width="25%">
<figcaption align = "center">
<font size = "2">
Fig.6 - Discretization scheme (Fetzer (2018))<sup>4</sup>
</font>
</figcaption>

# Example: Soil-Water Evaporation

## Soil-Water Evaporation: Soil-Water Evaporation

<img src=img/FFPM-TurbulentBoundaryLayer.png width="40%">

## Example: Soil-Water Evaporation
<img src=img/FFPM-SoilWaterEvapField.png width="40%">

<figcaption align = "center">
<font size = "2">
Fig.7 - Evaporation in the water cycle (Shahraeeni et al. (2012))<sup>5</sup>
</font>
</figcaption>

## Example: Soil-Water Evaporation

<img src=img/FFPM-evapStages.png width="60%">

<figcaption align = "center">
<font size = "2">
Fig.8 - Different evaporation stages (Or et al.(2013))<sup>6</sup>
</font>
</figcaption>

## Example: Simple Evaporation Setup

![](img/FFPM_evaporation_setup.png){style="width: 60%; margin: auto; float: left;"}

<font size = "2">
 Tab1: Input parameter
</font>

<font size = "5">

| Parameter                   | Value         |
|:----------------------------|--------------:|
| $\textbf{v}_g^{ff}$ [m/s]   | (3.5,0)$^T$   |
| $p_g^{ff}$ [Pa]             | 1e5           |
| $X_g^{w,ff}$ [-]            | 0.008         |
| $T^{ff}$ [K]                | 298.15        |
| $p_g^{pm}$ [Pa]             | 1e5           |
| $S_l^{pm}$ [-]              | 0.98          |
| $T^{pm}$ [K]                | 298.15        |

</font>

<figcaption align = "left">
<font size = "2">
Fig.9 - Model setup (Fetzer (2018))<sup>4</sup>
</font>
</figcaption>


## Example: Results

![](img/FFPM_evaporation.gif)
<figcaption align = "center">
<font size = "2">
Fig.10 - Results: Evaporation from a simple setup (Fetzer (2018))<sup>4</sup>
</font>
</figcaption>

# Exercises

## Exercise: Interface

_Tasks_

- Change flow direction for a tangential flow as opposed to the original-normal flow
- Introduce the Beavers-Joseph-tangential-flow interface condition
- Redevelop the grid and introduce an undulating interface
- Change the inflow boundary condition to a velocity profile

## Exercise: Models

_Tasks_

- Modify the model to use a 2-phase multicomponent model in the porous medium
- Experiment with various data output types: `.csv` and `.json`
- Visualize with various visualization tools: `gnuplot` and `matplotlib`

## Exercise: Turbulence

_Tasks_

- Introduce a turbulence model to the free-flow domain
- Reduce the free-flow domain by using a symmetry condition at the upper domain boundary
- Vary grid resolution and perform a qualitative grid convergence test

# References

##

<font size = "5">

1. Heck, K., Coltman, E., Schneider, J. and Helmig, R. (2020). Influence of radiation on evaporation rates: A numerical analysis. Water Resources Research, 56, e2020WR027332. https://doi.org/10.1029/2020WR027332

2. Schneider, M., Gläser, D., Weishaupt, K., Coltman, E., Flemisch, B. and Helmig, R. (2023). Coupling staggered-grid and vertex-centered finite-volume methods for coupled porous-medium free-flow problems. Journal of Computational Physics. 112042. https://doi.org/10.1016/j.jcp.2023.112042.

3. Koch, T., Flemisch, B., Helmig, R., Wiest, R. and Obrist, D. (2020). A multiscale subvoxel perfusion model to estimate diffusive capillary wall conductivity in multiple sclerosis lesions from perfusion MRI data. Int J Numer Meth Biomed Engng. 36:e3298. https://doi.org/10.1002/cnm.

4. Fetzer, Thomas: Coupled Free and Porous-Medium Flow Processes Affected by Turbulence and Roughness – Models, Concepts and Analysis, Universität Stuttgart. - Stuttgart: Institut für Wasser- und Umweltsystemmodellierung, 2018

5. Shahraeeni, E., Lehmann, P. and Or, D. (2012). Coupling of evaporative fluxes from drying porous surfaces with air boundary layer: Characteristics of evaporation from discrete pores. Water Resources Research. 48. 9525-. 10.1029/2012WR011857.

6. Or, D., Lehmann, P., Shahraeeni, E. and Shokri, N. (2013), Advances in Soil Evaporation Physics—A Review. Vadose Zone Journal, 12: 1-16 vzj2012.0163. https://doi.org/10.2136/vzj2012.0163

</font>
